#!/usr/bin/perl -w
use strict;
use Spreadsheet::ParseExcel;

binmode STDOUT, ":utf8";

my $oExcel = new Spreadsheet::ParseExcel;

die "You must provide a filename to $0 to be parsed as an Excel file" unless $ARGV[0];
die "You must provide a filename to $0 to create a .H and .C file" unless $ARGV[1];

# open Excel file
my $oBook = $oExcel->Parse($ARGV[0]);
my ($iR, $iC, $oWkS, $oWkC);
# print "FILE :" . $oBook->{File} . "\n";
# print "COUNT:" . $oBook->{SheetCount} . "\n";

# open output files
my $hFile = $ARGV[1] . ".h";
my $hFileUpper = $ARGV[1] . "_H";
$hFileUpper =~ tr/a-z/A-Z/;

open HFILE, ">", $hFile or die $!;
binmode HFILE, ":utf8";

my $cFile = $ARGV[1] . ".c";
open CFILE, ">", $cFile or die $!;
binmode CFILE, ":utf8";

# print H file header
print HFILE "#ifndef __" . $hFileUpper . "__\n";
print HFILE "#define __" . $hFileUpper . "__\n\n";
print HFILE "#include <avr/pgmspace.h>\n\n";
print HFILE "#define START_CHAR 1\n";
print HFILE "#define END_CHAR 255\n";
print HFILE "#define CHAR_LEN 5\n";
print HFILE "\n";
print HFILE "extern prog_uint8_t font_data[END_CHAR-START_CHAR+1][CHAR_LEN];\n";
print HFILE "\n";
print HFILE "#endif // __". $hFileUpper . "__\n";

# print C file header

print CFILE "#include \"". $hFile . "\"\n";
print CFILE "\n";
print CFILE "prog_uint8_t font_data[END_CHAR-START_CHAR+1][CHAR_LEN] = {\n";

# select worksheet number 0
$oWkS = $oBook->{Worksheet}[0];

# print "------- SHEET:" . $oWkS->{Name} . "\n";

#  search each row for data in columns 23 -> 27
for (my $iR = $oWkS->{MinRow} + 1; defined $oWkS->{MaxRow} && $iR <= $oWkS->{MaxRow}; $iR = $iR + 9)
{
	printf CFILE "\t{";
	for (my $iC = 22; $iC < 27; $iC++)
	{
  		$oWkC = $oWkS->{Cells}[$iR][$iC];
  	
		if (defined $oWkC->{Val}) {
			# print out the contents of a cell  
  			printf CFILE "%s", $oWkC->Value;
		}
		if ($iC != 26) {
			printf CFILE ", ";
		}
		else {
			printf CFILE "},";
		}
	}
 
 $oWkC = $oWkS->{Cells}[$iR][22];
 if ($oWkC) {
	$oWkC = $oWkS->{Cells}[$iR][1];
	if (defined  $oWkC->{Val}) {
		printf CFILE " // %4s ", $oWkC->Value;
	}
	$oWkC = $oWkS->{Cells}[$iR][0];
	if (defined  $oWkC->{Val}) { 
		printf CFILE "%s\n", $oWkC->Value;
	}
 }
}
print HFILE "\n";
print CFILE "};\n";
close HFILE;
close CFILE;

