#!/usr/bin/perl -w

use strict;
use Win32::OLE qw(in with);
use Win32::OLE::Const 'Microsoft Excel';
use Win32::OLE::Variant;
binmode STDOUT, ":utf8";

$Win32::OLE::Warn = 3;                                # die on errors...

die "You must provide a filename to $0 to be parsed as an Excel file" unless $ARGV[0];
die "You must provide a filename to $0 to create a .H and .C file" unless $ARGV[1];

# get already active Excel application or open new
my $Excel = Win32::OLE->GetActiveObject('Excel.Application')
    || Win32::OLE->new('Excel.Application', 'Quit');  

# open output files
my $hFile = $ARGV[1] . ".h";
my $hFileUpper = $ARGV[1] . "_H";
$hFileUpper =~ tr/a-z/A-Z/;

open HFILE, ">", $hFile or die $!;
binmode HFILE, ":utf8";

my $cFile = $ARGV[1] . ".c";
open CFILE, ">", $cFile or die $!;
binmode CFILE, ":utf8";

# print H file header
print HFILE "#ifndef __" . $hFileUpper . "__\n";
print HFILE "#define __" . $hFileUpper . "__\n\n";
print HFILE "#include <avr/pgmspace.h>\n\n";
print HFILE "#define START_CHAR 1\n";
print HFILE "#define END_CHAR 255\n";
print HFILE "#define CHAR_LEN 5\n";
print HFILE "\n";
print HFILE "extern prog_uint8_t font_data[END_CHAR-START_CHAR+1][CHAR_LEN];\n";
print HFILE "\n";
print HFILE "#endif // __". $hFileUpper . "__\n";

# print C file header
print CFILE "#include \"". $hFile . "\"\n";
print CFILE "\n";
print CFILE "prog_uint8_t font_data[END_CHAR-START_CHAR+1][CHAR_LEN] = {\n";

# open Excel file
my $Book = $Excel->Workbooks->Open($ARGV[0]); 

# select worksheet number 1 
my $Sheet = $Book->Worksheets(1);

#  search each row for data in columns 23 -> 27
for (my $row = 2; $row < 2290 ; $row = $row + 9) {
	printf CFILE "\t{";
	foreach my $col (23..27) {
		# skip empty cells
		next unless defined $Sheet->Cells($row,$col)->{'Value'};

		# print out the contents of a cell  
		printf CFILE "%s", $Sheet->Cells($row,$col)->{'Value'};
		
		if ($col != 27){
			printf CFILE ", ";
		}
		else {
			printf CFILE "},";
		}
	}
 
	if (defined $Sheet->Cells($row,23)->{'Value'}) {
		printf CFILE " // %4s %3s\n", $Sheet->Cells($row,2)->{'Value'}, $Sheet->Cells($row,1)->{'Value'};
	} 
}

# clean up after ourselves
print HFILE "\n";
print CFILE "};\n";
close HFILE;
close CFILE;
#$Book->Close;